/* Thunderbird Equations
  Author: Josh Eads <jmer43@mst.edu>
  Version: 1.2.1 - April 2, 2009
*/

// ====================================================================
//       URLEncode and URLDecode functions
//
// Copyright Albion Research Ltd. 2002
// http://www.albionresearch.com/
//
// You may copy these functions providing that 
// (a) you leave this copyright notice intact, and 
// (b) if you use these functions on a publicly accessible
//     web site you include a credit somewhere on the web site 
//     with a link back to http://www.albionresearch.com/
//
// If you find or fix any bugs, please let us know at albionresearch.com
//
// SpecialThanks to Neelesh Thakur for being the first to
// report a bug in URLDecode() - now fixed 2003-02-19.
// And thanks to everyone else who has provided comments and suggestions.
// ====================================================================

var equations = {
  urlEncode: function(input) {
	// The Javascript escape and unescape functions do not correspond
	// with what browsers actually do...
	var SAFECHARS = "0123456789" +					// Numeric
					"ABCDEFGHIJKLMNOPQRSTUVWXYZ" +	// Alphabetic
					"abcdefghijklmnopqrstuvwxyz" +
					"-_.!~*'()";					// RFC2396 Mark characters
	var HEX = "0123456789ABCDEF";

	var plaintext = input; //document.URLForm.F1.value;
	var encoded = "";
	for (var i = 0; i < plaintext.length; i++ ) {
		var ch = plaintext.charAt(i);
	    if (ch == " ") {
		    encoded += "+";				// x-www-urlencoded, rather than %20
		} else if (SAFECHARS.indexOf(ch) != -1) {
		    encoded += ch;
		} else {
		    var charCode = ch.charCodeAt(0);
			if (charCode > 255) {
			    alert( "Unicode Character '" 
                        + ch 
                        + "' cannot be encoded using standard URL encoding.\n" +
				          "(URL encoding only supports 8-bit characters.)\n" +
						  "A space (+) will be substituted." );
				encoded += "+";
			} else {
				encoded += "%";
				encoded += HEX.charAt((charCode >> 4) & 0xF);
				encoded += HEX.charAt(charCode & 0xF);
			}
		}
	} // for

	//document.URLForm.F2.value = encoded;
    //document.URLForm.F2.select();
	return encoded;
  },
  onLoad: function() {
    // initialization code
    this.initialized = true;
    this.installButton();
  },
  installButton: function() {
      /*var toolbarholder = document.getElementById("composeToolbar2");
      toolbarholder.insertBefore("equations-toolbar-button", null);*/

      try {
         var tbirdnav = document.getElementById("composeToolbar2"); // use "nav-bar" in Firefox 2 and earlier
         var curSet = tbirdnav.currentSet;
         if (curSet.indexOf("equations-toolbar-button") == -1)
         {
           set = curSet.replace(/button-save/, "button-save,equations-toolbar-button");
           tbirdnav.setAttribute("currentset", set);
           tbirdnav.currentSet = set;
           document.persist("composeToolbar2", "currentset");
           // If you don't do the following call, funny things happen
           try {
             BrowserToolboxCustomizeDone(true);
           }
           catch (e) { }
         }
       }
       catch(e) { }
  },
  onToolbarButtonCommand: function(e) {
   /*get the editor object*/
    var editor = document.getElementById("content-frame");
    var htmlEditor = editor.getHTMLEditor(editor.contentWindow);

   /*grab the document and <body> portion of the editor*/
    var editorDoc = editor.contentDocument;
   var body = editorDoc.childNodes[1].innerHTML; //copy of body
   //alert(body);

   /*parse out the $$latex$$ portions*/
   var latexRegEx = /\$\$.*?\$\$/;
   var matchPos1 = body.search(latexRegEx);
   if(matchPos1 == -1)
      alert("Notice: LaTeX equations must be surrounded by '$$', such as: $$\\frac{3}{2}$$");
   var curMatch = 1;
   //alert(body);
   while(matchPos1 != -1) //while another match has been found
   {
      //alert("Matched $$...$$ at position: " + matchPos1);
      var tempStr = String(body.match(/\$\$.*?\$\$/));
      var matchStr = tempStr.substring(2, tempStr.length-2);
      body = body.replace(latexRegEx, '<img src="http://l.wordpress.com/latex.php?latex=' + 
        equations.urlEncode(matchStr) + '&bg=ffffff&fg=000000&s=0' + '" alt="$' + matchStr + '$">');
      //editorDoc.childNodes[1].innerHTML = editorDoc.childNodes[1].innerHTML.replace(latexRegEx, "bob");
      curMatch++;
      matchPos1 = body.search(latexRegEx); //this goes to the next since the first was replaced
      //alert(body);
   }
   //alert(String(body));
   //editorDoc.childNodes[1].innerHTML = body;
   //editor.makeEditable("htmlmail", 0);
   editor.getHTMLEditor(editor.contentWindow).rebuildDocumentFromSource(body);
  }
};
window.addEventListener("load", function(e) { equations.onLoad(e); }, false);
